import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { setRoleStatus } from '@/api/demo/system';
import { useMessage } from '@/hooks/web/useMessage';

import { getDepartmentList } from '@/api/project/settlementManage';
import {useUserStore} from "@/store/modules/user";

const deptId = useUserStore().userInfo.deptParentId;
type CheckedType = boolean | string | number;
//主模块-结算管理列表页
export const columns: BasicColumn[] = [
  {
    title: '填报周期',
    dataIndex: 'yearQuarter',
    width: 140,
  },
  {
    title: '项目数量',
    dataIndex: 'uniqueProjectCount',
    width: 140,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 140,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 140,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 140,
  },
  {
    title: '审核状态',
    dataIndex: 'statusResult',
    ifShow: deptId != '100',
    width: 140,
  },
  {
    title: '审核人',
    dataIndex: 'auditor',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'auditTime',
    width: 140,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'givenYear',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      picker: 'year',
      style: { width: '100%' },
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    field: 'quarter',
    label: '',
    component: 'Select',
    componentProps: {
      options: [
        { label: '第一季度', value: '第一季度' },
        { label: '第二季度', value: '第二季度' },
        {
          label: '第三季度',
          value: '第三季度',
        },
        {
          label: '第四季度',
          value: '第四季度',
        },
      ],
      placeholder: '季度',
    },
    colProps: { span: 4 },
  },
  {
    field: 'companyName',
    label: '',
    component: 'Select',
    ifShow: deptId === '100',
    componentProps: {
      // options: getDepartment(),
      options: [
        { label: '公司名称1', value: '1' },
        { label: '公司名称2', value: '0' },
      ],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'projectName',
    label: '项目名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'fundingSource',
    label: '资金来源',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },

  {
    //    //project_investment
    field: 'projectInvestment',
    label: '立项投资额',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },

  {
    //bidding_method
    field: 'biddingMethod',
    label: '招标方式',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '建委招标',
          value: '1',
        },
        {
          label: '平台招标',
          value: '2',
        },
        {
          label: '邀标比选',
          value: '3',
        },
        {
          label: '直接委托',
          value: '4',
        },
        {
          label: '评分定离',
          value: '5',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },

  {
    //contrac_ype
    field: 'contracYpe',
    label: '合同类型',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '施工',
          value: '1',
        },
        {
          label: '监理',
          value: '2',
        },
        {
          label: '设计',
          value: '3',
        },
        {
          label: '图审',
          value: '4',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    //contract_name
    field: 'contractName',
    label: ' 合同名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true
    },
    colProps: { span: 7, offset: 1 },
  },

  {
    //first_party_name

    field: 'firstPartyName',
    label: '甲方单位名称',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'secondPartyName',
    //second_party_name
    label: '乙方单位名称',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    //form_of_contract
    field: 'formOfContract',
    label: '合同形式',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '固定总价',
          value: '1',
        },
        {
          label: '固定单价',
          value: '2',
        },
        {
          label: '费率',
          value: '3',
        },
        {
          label: '其他',
          value: '4',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    //contract_signing_time
    field: 'contractSigningTime',
    label: '合同签订日期',
    required: true,
    component: 'DatePicker',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      valueFormat: 'YYYY-MM-DD',
      style: {
        width: '100%',
      },
    },
  },

  {
    field: 'closingTime',
    //closing_time
    label: '竣工时间',
    required: true,
    component: 'DatePicker',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      valueFormat: 'YYYY-MM-DD',
      style: {
        width: '100%',
      },
    },
  },
  {
    //closing_time_datetime
    field: 'closingTimeDatetime',
    label: '结算完成时间',
    required: true,
    component: 'DatePicker',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      valueFormat: 'YYYY-MM-DD',
      style: {
        width: '100%',
      },
    },
  },

  {
    //contract_amount
    field: 'contractAmount',
    label: '合同金额',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel, formActionType }) => ({
      addonAfter: '万元',
      readonly: true,
      disabled: true,
      onChange: (value) => {
        formModel.contractAmount = value;
        updateProportionContractAmount(formModel, formActionType);
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    //submitted_for_settlement
    field: 'submittedForSettlement',
    label: '签证变更金额:',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    //super_contract_scale
    field: 'superContractScale',
    label: '结算报送金额',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    //sum_of_money
    field: 'sumOfMoney',
    label: '结算审定金额',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel, formActionType }) => ({
      addonAfter: '万元',
      onChange: (value) => {
        formModel.sumOfMoney = value;
        updateProportionContractAmount(formModel, formActionType);
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    //proportion_contract_amount
    field: 'proportionContractAmount',
    label: '结算审核金额超合同额比例',
    labelWidth: '300px',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '%',
      readonly: true,
      disabled: true,
      precision: 2, // 设置小数点后两位
    },
    colProps: { span: 7, offset: 1 },
  },
  // {
  //   field: 'investmentAmount',
  //   label: '结算审核金额超合同额比例',
  //   labelWidth:"300px",
  //   required: true,
  //   show:false,
  //   component: 'Input',
  //   componentProps: {
  //     addonAfter: '元',
  //   },
  //   colProps: { span: 7, offset: 1 },
  // },
  {
    //meeting_minutes
    label: '会议纪要',
    field: 'meetingMinutes',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    //remark
    label: '备注',
    field: 'remark',
    // required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
];
async function getDepartment() {
  const data = await getDepartmentList();
  console.log('数据仓库');
  return data;
}

// 辅助函数用于更新 proportionContractAmount
function updateProportionContractAmount(formModel, formActionType) {
  const { contractAmount, sumOfMoney } = formModel;

  if (contractAmount && sumOfMoney) {
    const ratio =
      ((parseFloat(sumOfMoney) - parseFloat(contractAmount)) / parseFloat(contractAmount)) * 100;
    formModel.proportionContractAmount = ratio.toFixed(2); // 将比例保留两位小数
  } else {
    formModel.proportionContractAmount = null; // 如果任何一个为空，则清空比例
  }

  // 触发表单更新
  formActionType.setFieldsValue({ proportionContractAmount: formModel.proportionContractAmount });
}
